@@ -421,9 +421,9 @@ class _ImageBase(martist.Artist, cm.ScalarMappable):
 
                 A_scaled -= a_min
                 # a_min and a_max might be ndarray subclasses so use
-                # asscalar to avoid errors
-                a_min = np.asscalar(a_min.astype(scaled_dtype))
-                a_max = np.asscalar(a_max.astype(scaled_dtype))
+                # item to avoid errors
+                a_min = a_min.astype(scaled_dtype).item()
+                a_max = a_max.astype(scaled_dtype).item()
 
                 if a_min != a_max:
                     A_scaled /= ((a_max - a_min) / 0.8)
@@ -1447,9 +1447,9 @@ def pil_to_array(pilImage):
         # return MxN luminance array of uint16
         raw = pilImage.tobytes('raw', pilImage.mode)
         if pilImage.mode.endswith('B'):
-            x = np.fromstring(raw, '>u2')
+            x = np.frombuffer(raw, '>u2')
         else:
-            x = np.fromstring(raw, '<u2')
+            x = np.frombuffer(raw, '<u2')
         return x.reshape(pilImage.size[::-1]).astype('=u2')
     else:  # try to convert to an rgba image
         try:
